Index: uspace/lib/c/generic/stats.c
===================================================================
--- uspace/lib/c/generic/stats.c	(revision e535eeb8ca65f325690f9d79d60ea2f3c9e9da35)
+++ uspace/lib/c/generic/stats.c	(revision bd01a4e2eea1f1c2d0ae1323bcebe495b503e8a1)
@@ -96,23 +96,23 @@
 }
 
-/** Get task IDs
- *
- * @param count Number of IDs returned.
- *
- * @return Array of IDs (task_id_t).
- *         If non-NULL then it should be eventually freed
- *         by free().
- *
- */
-task_id_t *stats_get_tasks(size_t *count)
-{
-	size_t size = 0;
-	task_id_t *ids =
-	    (task_id_t *) sysinfo_get_data("system.tasks", &size);
-	
-	assert((size % sizeof(task_id_t)) == 0);
-	
-	*count = size / sizeof(task_id_t);
-	return ids;
+/** Get task statistics
+ *
+ * @param count Number of records returned.
+ *
+ * @return Array of stats_task_t structures.
+ *         If non-NULL then it should be eventually freed
+ *         by free().
+ *
+ */
+stats_task_t *stats_get_tasks(size_t *count)
+{
+	size_t size = 0;
+	stats_task_t *stats_tasks =
+	    (stats_task_t *) sysinfo_get_data("system.tasks", &size);
+	
+	assert((size % sizeof(stats_task_t)) == 0);
+	
+	*count = size / sizeof(stats_task_t);
+	return stats_tasks;
 }
 
@@ -140,23 +140,23 @@
 }
 
-/** Get thread IDs
- *
- * @param count Number of IDs returned.
- *
- * @return Array of IDs (thread_id_t).
- *         If non-NULL then it should be eventually freed
- *         by free().
- *
- */
-thread_id_t *stats_get_threads(size_t *count)
-{
-	size_t size = 0;
-	thread_id_t *ids =
-	    (thread_id_t *) sysinfo_get_data("system.threads", &size);
-	
-	assert((size % sizeof(thread_id_t)) == 0);
-	
-	*count = size / sizeof(thread_id_t);
-	return ids;
+/** Get thread statistics.
+ *
+ * @param count Number of records returned.
+ *
+ * @return Array of stats_thread_t structures.
+ *         If non-NULL then it should be eventually freed
+ *         by free().
+ *
+ */
+stats_thread_t *stats_get_threads(size_t *count)
+{
+	size_t size = 0;
+	stats_thread_t *stats_threads =
+	    (stats_thread_t *) sysinfo_get_data("system.threads", &size);
+	
+	assert((size % sizeof(stats_thread_t)) == 0);
+	
+	*count = size / sizeof(stats_thread_t);
+	return stats_threads;
 }
 
